@@ -72,18 +72,18 @@ def neurondb_dataframe(neurondb: Path, morphology_dir: Optional[Path] = None) ->
             neuronDB = xmltodict.parse(fd.read())
 
         rows = list()
-        for morph in _ensure_list(neuronDB["neurondb"]["listing"]["morphology"]):
-            assert morph["repair"]["use_axon"] in {'true', 'false', 'True', 'False', None}
+        for morph in filter(None, _ensure_list(neuronDB["neurondb"]["listing"]["morphology"])):
+            use_axon = morph.get("repair", {}).get("use_axon")
+            assert use_axon in {'true', 'false', 'True', 'False', None}
             rows.append(
                 (morph["name"],
                  morph["layer"],
                  morph["mtype"] + (":" + morph["msubtype"] if morph["msubtype"] else ""),
                  # According to Eilif, an empty use_axon (corresponding to a null in the database)
                  # means that the axon is supposed to be used
-                 (morph["repair"]["use_axon"] in {'true', 'True', None})))
+                 (use_axon in {'true', 'True', None})))
 
         df = pd.DataFrame(data=rows, columns=['name', 'layer', 'mtype', 'use_axon'])
-
     else:
         raise ValueError(f'Unrecognized extension for neurondb file: {neurondb}')
 
